@@ -28,7 +28,7 @@ class Sale(metaclass=PoolMeta):
         weights = []
         context['weights'] = weights
 
-        lines = [l for l in self.lines or [] if l.quantity > 0]
+        lines = [l for l in self.lines or [] if l.quantity and l.quantity > 0]
         keyfunc = partial(self._group_parcel_key, lines)
         lines = sorted(lines, key=keyfunc)
 
